#!/usr/bin/env python3

import os
import socket


class ApBootstrapInitialBoot(object):
    def __init__(self, initial_boot_datetime: str, initial_boot_csv_path: str, initial_boot_csv_destination: str, watchdog_csv_dir: str):

        # Variables passed in during initialization
        self.initial_boot_datetime = initial_boot_datetime
        self.initial_boot_csv_path = initial_boot_csv_path
        self.initial_boot_csv_destination = initial_boot_csv_destination
        self.watchdog_csv_dir = watchdog_csv_dir
        self.hostname = socket.gethostname()

    # Writing the initial-boot file to disk to record when the machine was initially imaged
    def write_initial_boot_file(self) -> bool:
        # dm_output = io.StringIO()
        #
        # dm_output.write(self.hostname + ",Ok,LinuxInstallDateTime," + self.initial_boot_datetime + "\r\n")

        dm_output = self.hostname + ",Ok,LinuxInstallDateTime," + self.initial_boot_datetime + "\n"

        # print ("apbootstrap_initial_boot: initial-boot content: \n\t" + "\n".join(dm_output.getvalue().split("\r\n")))
        try:
            print("\napbootstrap_initial_boot: Writing initial-boot csv file: " + self.initial_boot_csv_path + "\n")
            with open(self.initial_boot_csv_path, 'w', newline="\r\n") as file:

                file.write(dm_output)

        except Exception as e:
            print("apbootstrap_initial_boot: Exception: " + str(e))
            return False

        return True

    # The initial boot file needs to be copied to the csv dir so that it can be pushed to DM regularly
    def copy_initial_boot_file(self) -> bool:

        if os.path.isfile(self.initial_boot_csv_destination):
            print("machinelocalwatchdog.copy_initial_boot_file: initial-boot csv_sources file already copied")
            return True

        elif os.path.exists(self.watchdog_csv_dir):
            with open(self.initial_boot_csv_destination, "wb") as outfile:
                with open(self.initial_boot_csv_path, "rb") as infile:
                    outfile.write(infile.read())
            print("Copying File: " + self.initial_boot_csv_path + " to: " + self.initial_boot_csv_destination)

        else:
            print("machinelocalwatchdog.copy_initial_boot_file: initial-boot csv_sources file does not exist")
            return False

        return True

    # Function that walks through the steps necessary to configure initial-boot by calling other functions
    def configure_initial_boot(self) -> bool:
        if not (self.write_initial_boot_file()):
            print("apbootstrap_initial_boot: Could not write " + self.initial_boot_csv_path + " (configure_initial_boot.write_apt_proxy_file)")
            return False

        if not (self.copy_initial_boot_file()):
            print("apbootstrap_initial_boot: Could not copy " + self.initial_boot_csv_path + " (configure_initial_boot.copy_initial_boot_file)")
            return False

        return True
