#!/usr/bin/env python3

import sys

# if script's parent directory isn't in sys.path, then add it
if ('/'.join(sys.path[0].split("/")[:-1]) not in sys.path):
    sys.path.append('/'.join(sys.path[0].split("/")[:-1]))

from apcommon import iniparser


class ApBootstrapMachineEnv(object):
    def __init__(self, linux_bootstrap_ini_path="", global_environment_sh_path="", docker_bridge_ip=""):

        # Variables passed in during initialization
        self.linux_bootstrap_ini_path = linux_bootstrap_ini_path
        self.global_environment_sh_path = global_environment_sh_path
        self.docker_bridge_ip = docker_bridge_ip

        # Initialize all objects and parsers so we have them available right away
        self.linux_bootstrap_ini_parser_object = iniparser.INIParser(self.linux_bootstrap_ini_path)

        self.global_environment_variables = []

    # Generic abstraction function to call read on any iniparser object
    def read_ini(self, ini_object) -> bool:
        if (ini_object.read()):
            return True
        else:
            return False

    # Get global ENV VARS so we can write those to each system we install on
    def get_global_environment_variables(self) -> bool:
        self.global_environment_variables.append({"AP_CLUSTER": self.linux_bootstrap_ini_parser_object.get("Config", "AutopilotCluster")})
        self.global_environment_variables.append({"AP_ENVIRONMENT": self.linux_bootstrap_ini_parser_object.get("Config", "AutopilotEnvironment")})
        self.global_environment_variables.append({"AP_MACHINE_FUNCTION": self.linux_bootstrap_ini_parser_object.get("Config", "AutopilotMachineFunction")})
        self.global_environment_variables.append({"AP_MACHINE_NAME": self.linux_bootstrap_ini_parser_object.get("Config", "AutopilotDeviceName")})
        self.global_environment_variables.append({"AP_DOCKER_BRIDGE_ADDR": self.docker_bridge_ip})

        if len(self.global_environment_variables) < 4:
            return False

        return True

    # Write global ENV VARS to the path for the OS we're on
    def write_global_environment_variables(self) -> bool:
        print("\napbootstrap_machine_env: Writing ENV VAR profile script: " + self.global_environment_sh_path + "\n")
        try:
            with open(self.global_environment_sh_path, 'w', newline="\n") as file_sh:
                for idx, item in enumerate(self.global_environment_variables):
                    # print(item)
                    for key, value in self.global_environment_variables[idx].items():
                        print("\t" + key + ": " + value)

                        file_sh.write("export " + key + "=\"" + value + "\"\n")

        except Exception as e:
            print("apbootstrap_machine_env: Exception: " + str(e))
            return False

        print("\n")

        return True

    # Function that walks through the steps necessary to configure machine env variables by calling other functions
    def configure_machine_env(self) -> bool:
        if (not self.read_ini(self.linux_bootstrap_ini_parser_object)):
            print("apbootstrap_configure_machine_env: Could not read linux_bootstrap.ini (linux_bootstrap_ini_parser_object.read_ini)")
            return False

        if (not self.get_global_environment_variables()):
            print("apbootstrap_configure_machine_env: Could not get global environment variables (get_global_environment_variables)")
            return False

        if (not self.write_global_environment_variables()):
            print("apbootstrap_configure_machine_env: Could not write global environment variables (write_global_environment_variables)")
            return False

        return True
