#!/usr/bin/env python3

import sys

# if script's parent directory isn't in sys.path, then add it
if ('/'.join(sys.path[0].split("/")[:-1]) not in sys.path):
    sys.path.append('/'.join(sys.path[0].split("/")[:-1]))

from apsdk import apenv
from apcommon import apsecretclient


class ACRSecretRefresher:
    ACR_SECRET_NAME = "ACRConnectionData"

    def __init__(self, client_key_file, client_cert_file):
        self.key_file = client_key_file
        self.cert_file = client_cert_file

        self.connection_string = ""
        self.client_id = ""
        self.client_key = ""

    def __get_connection_string(self):
        client = apsecretclient.APSecretClient(self.key_file, self.cert_file)
        self.connection_string = client.read_cache_secret(self.ACR_SECRET_NAME)

    def __parse_connection_string(self):
        if self.connection_string == "":
            raise ValueError("Received empty string")

        # connection_string is expected to be stored in 'CLIENT_ID\CLIENT_KEY' format
        parts = self.connection_string.split('\\')
        if len(parts) != 2:
            raise ValueError("Unexpected format for acr secret")

        self.client_id = parts[0]
        self.client_key = parts[1]

    def print_acr_connection_data(self):
        self.__get_connection_string()
        self.__parse_connection_string()
        print(self.client_id)
        print(self.client_key)


def main():
    client_key, client_cert = apenv.get_machine_function_cert()
    refresher = ACRSecretRefresher(client_key, client_cert)

    try:
        refresher.print_acr_connection_data()
    except Exception as e:
        print("ERROR: {0}".format(e), file=sys.stderr)
        sys.exit(1)

    sys.exit(0)


if __name__ == '__main__':
    main()
