#!/bin/bash
# Service that renews Machine and Machine function certs on the machine
set -e
set -x

# Certs are issued with two month validity. Lets renew it every 5 days for now.
DAYS_TO_RENEW=55

AP_ROOT=/ap
MACHINE_NAME=$(hostname)
BOOTSTRAP_INI=${AP_ROOT}/data/LinuxBootstrapData.ini
MACHINE_CERT_DIR=${AP_ROOT}/data/certs/machine
MACHINE_CERT=${AP_ROOT}/data/certs/machine/${MACHINE_NAME}.crt
MAFUNCT_CERT=${AP_ROOT}/data/certs/machine_function/${MACHINE_NAME}.crt
INTERMEDIATE_DIR=/usr/share/ca-certificates/ap

if [ ! -f "${BOOTSTRAP_INI}" ] || [ ! -r "${BOOTSTRAP_INI}" ]; then
    print "ERROR: Could not find ${BOOTSTRAP_INI}. Or isn't readable"
    exit 1
fi

# Get APCA VIP Info
APCA_VIP=$(awk -F"=" '/AutopilotAPCAVip/ {print $2}' ${BOOTSTRAP_INI})
if [ "${APCA_VIP}" == "" ] ; then
    print "ERROR: Could not find AutopilotAPCAVip in ${BOOTSTRAP_INI}. Cannot proceed."
    exit 1
fi

# Get IP
AP_IP=$(awk -F"=" '/AutopilotIPAddress/ {print $2}' ${BOOTSTRAP_INI})
if [ "${AP_IP}" == "" ] ; then
    print "ERROR: Could not find AutopilotIPAddress in ${BOOTSTRAP_INI}. Cannot proceed."
    exit 1
fi

# Renew Intermediate Certificates
${AP_ROOT}/app/localcertagent/localcertagent.py -e -n ${MACHINE_NAME} -s ${APCA_VIP} -i ${AP_IP} -f ${INTERMEDIATE_DIR}

# Renew Machine and Machine Function Certificates
${AP_ROOT}/app/localcertagent/localcertagent.py -r -w ${DAYS_TO_RENEW} -n ${MACHINE_NAME} -s ${APCA_VIP} -i ${AP_IP} -f ${MACHINE_CERT_DIR}

# Get cert info 
openssl x509 -in ${MACHINE_CERT} -text -noout -certopt no_header,no_version,no_signame,no_pubkey,no_sigdump,no_aux,no_serial
openssl x509 -in ${MAFUNCT_CERT} -text -noout -certopt no_header,no_version,no_signame,no_pubkey,no_sigdump,no_aux,no_serial
